==> zio-aws-cloudformation_2.12-5.17.102.7-sources.jar: zio/aws/cloudformation/model/StackDriftInformation.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class StackDriftInformation(
    stackDriftStatus: zio.aws.cloudformation.model.StackDriftStatus,
    lastCheckTimestamp: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.StackDriftInformation = {
    import StackDriftInformation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
      .builder()
      .stackDriftStatus(stackDriftStatus.unwrap)
      .optionallyWith(
        lastCheckTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastCheckTimestamp)
      .build()
  }
  def asReadOnly: zio.aws.cloudformation.model.StackDriftInformation.ReadOnly =
    zio.aws.cloudformation.model.StackDriftInformation.wrap(buildAwsValue())
}
object StackDriftInformation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.StackDriftInformation =
      zio.aws.cloudformation.model.StackDriftInformation(
        stackDriftStatus,
        lastCheckTimestamp.map(value => value)
      )
    def stackDriftStatus: zio.aws.cloudformation.model.StackDriftStatus
    def lastCheckTimestamp: Option[Timestamp]
    def getStackDriftStatus
        : ZIO[Any, Nothing, zio.aws.cloudformation.model.StackDriftStatus] =
      ZIO.succeed(stackDriftStatus)
    def getLastCheckTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastCheckTimestamp", lastCheckTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ) extends zio.aws.cloudformation.model.StackDriftInformation.ReadOnly {
    override val stackDriftStatus
        : zio.aws.cloudformation.model.StackDriftStatus =
      zio.aws.cloudformation.model.StackDriftStatus
        .wrap(impl.stackDriftStatus())
    override val lastCheckTimestamp: Option[Timestamp] = scala
      .Option(impl.lastCheckTimestamp())
      .map(value => zio.aws.cloudformation.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ): zio.aws.cloudformation.model.StackDriftInformation.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloudformation_2.12-6.20.42.2-sources.jar: zio/aws/cloudformation/model/StackDriftInformation.scala <==
package zio.aws.cloudformation.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.cloudformation.model.primitives.Timestamp
import scala.jdk.CollectionConverters._
final case class StackDriftInformation(
    stackDriftStatus: zio.aws.cloudformation.model.StackDriftStatus,
    lastCheckTimestamp: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.StackDriftInformation = {
    import StackDriftInformation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
      .builder()
      .stackDriftStatus(stackDriftStatus.unwrap)
      .optionallyWith(
        lastCheckTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastCheckTimestamp)
      .build()
  }
  def asReadOnly: zio.aws.cloudformation.model.StackDriftInformation.ReadOnly =
    zio.aws.cloudformation.model.StackDriftInformation.wrap(buildAwsValue())
}
object StackDriftInformation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.StackDriftInformation =
      zio.aws.cloudformation.model.StackDriftInformation(
        stackDriftStatus,
        lastCheckTimestamp.map(value => value)
      )
    def stackDriftStatus: zio.aws.cloudformation.model.StackDriftStatus
    def lastCheckTimestamp: Optional[Timestamp]
    def getStackDriftStatus
        : ZIO[Any, Nothing, zio.aws.cloudformation.model.StackDriftStatus] =
      ZIO.succeed(stackDriftStatus)
    def getLastCheckTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastCheckTimestamp", lastCheckTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ) extends zio.aws.cloudformation.model.StackDriftInformation.ReadOnly {
    override val stackDriftStatus
        : zio.aws.cloudformation.model.StackDriftStatus =
      zio.aws.cloudformation.model.StackDriftStatus
        .wrap(impl.stackDriftStatus())
    override val lastCheckTimestamp: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastCheckTimestamp())
      .map(value => zio.aws.cloudformation.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.StackDriftInformation
  ): zio.aws.cloudformation.model.StackDriftInformation.ReadOnly = new Wrapper(
    impl
  )
}
